function payments_today_counters (widget) {
    "use strict";

    var model= openerp;

    widget.PaymentsTodayCountersWidget = widget.Base.extend({
        template: 'PaymentsTodayCounters',
        accountVoucher: [],
        resCompany: [],
        resCurrecy: [],

        events: {
            'click a': 'showCustomers',
            'click h2': 'showCustomers',
        },

        init: function (parent) {
            this._super(parent, {
                width : 3,
                height: 2
            });
        },

        start: function () {
            var self = this;
            self.fetchInitial();
        },

        fetchInitial: function () {
            var self = this;
            self.$el.find('#morosidad').block({
                message: null,
                overlayCSS: {
                    backgroundColor: '#FAFAFA'
                }
            });

            self.$el.find('.widget-content.widget-loading').css('display','flex');

            self.fetchAccountVoucher().then(function (accountVoucher) {
                return accountVoucher;
            }).then(function (accountVoucher) {
                self.accountVoucher = accountVoucher;
                return self.fetchResCompany();
            }).then(function (resCompany) {
                self.resCompany = resCompany;
                return self.fetchResCurrecy(resCompany);
            }).then(function(resCurrecy){
                self.resCurrecy = resCurrecy;
                return self.fetchVoucherCurrency();
            });
        },
        // Account Voucher
        fetchAccountVoucher: function () {
            var self = this;
            var defer = $.Deferred();
            var hoy =moment().format('YYYY-MM-DD');
            var fields = ['id', 'amount', 'currency_id', 'payment_rate_currency_id'];
            var domain = [['state', '=', 'posted'], ['type', '=', 'payment'], ['date', '=', hoy]];
            var accountVoucher = new model.web.Model('account.voucher');

            accountVoucher.query(fields).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });
            return defer;
        },
        //Comapnia
        fetchResCompany: function () {
            var self = this;
            var defer = $.Deferred();
            var fields =['id','name', 'currency_id','logo'];
            var domain =[['id', '=', 1]];
            var resCompany = new model.web.Model('res.company');

            resCompany.query(fields).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });
            return defer;
        },
        // Moneda
        fetchResCurrecy : function(){
            var self = this;
            var defer = $.Deferred();
            var fields =['id','name', 'symbol', 'rate_silent', 'base', 'decimal_separator', 'decimal_places', 'thousands_separator', 'symbol_position'];
            var domain =[['active','=',true]];
            var resCurrecy = new model.web.Model('res.currency');

            resCurrecy.query(fields).filter(domain).all().then(function(results){
                defer.resolve(results);
            });

            return defer;
        },
        //   voucherCurrencyRate
        fetchVoucherCurrency: function () {
            var self = this;
            var newVoucher = [];
            var itemVoucher;
            var residual = 0;
            var company = self.resCompany.shift();
            var currencyBase = self.getCutrrency(company.currency_id[0]).shift();
            var currencyVoucher;

            for (var i = 0; i < self.accountVoucher.length; i++) {
                itemVoucher = self.accountVoucher[i];

                currencyVoucher =  self.getCutrrency(itemVoucher.payment_rate_currency_id[0]).shift();
                if(!currencyVoucher){
                    currencyVoucher = {};
                    currencyVoucher.rate_silent = currencyBase.rate_silent;
                }

                newVoucher.push({
                    amount : itemVoucher.amount,
                    amount_rate : (itemVoucher.amount * (currencyBase.rate_silent / currencyVoucher.rate_silent))
                });
            }

            if (newVoucher.length > 0) {
                residual = _.reduce(_.map(newVoucher, function (map) {
                    return map.amount_rate;
                }), function (memo, num) {
                    return memo + num;
                });
            }

            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.$el.find('.widget-content').find('a').text(accounting.formatMoney(residual, currencyBase.symbol, currencyBase.decimal_places, currencyBase.thousands_separator, currencyBase.decimal_separator))
            self.$el.find('#morosidad').unblock();
        },
        // Obtener la moneda
        getCutrrency: function (id) {
            var self = this;
            return _.filter(self.resCurrecy,function (item) {
                return item.id === id
            })
        },
        // modal
        showCustomers: function (e) {
            var self = this;
            if (self.accountVoucher.length === 0){
                model.web.notification.do_warn("Atención","Sin datos");
                return
            }
            var hoy =moment().format('YYYY-MM-DD');

            this.do_action({
                name:"Listado de pagos realizados hoy",
                type: 'ir.actions.act_window',
                res_model: "account.voucher",
                views: [[false, 'list'],[false, 'form']],
                target: 'new',
                domain: [['state', '=', 'posted'], ['type', '=', 'payment'], ['date', '=', hoy]],
                context: {},
                flags: {'form': {'action_buttons': false, 'options': {'mode': 'view'}}},
            });
        }
    });
}
